@@ -66,11 +66,19 @@ class Session(object):
     under this class and reused in the concrete classes.
     """
 
-    def __init__(self, name = "session", expire = EXPIRE_TIME):
+    def __init__(
+        self,
+        name = "session",
+        expire = EXPIRE_TIME,
+        sid = None,
+        address = None
+    ):
         object.__init__(self)
-        self.sid = self._gen_sid()
+        self.sid = sid if sid else self._gen_sid()
         self.name = name
-        self.expire = time.time() + self._to_seconds(expire)
+        self.address = address
+        self.create = time.time()
+        self.expire = self.create + self._to_seconds(expire)
         self.dirty = True
 
     def __len__(self):
@@ -110,6 +118,10 @@ class Session(object):
     def count(cls):
         return 0
 
+    @classmethod
+    def all(cls):
+        return {}
+
     @classmethod
     def open(cls):
         cls.gc()
@@ -177,7 +189,10 @@ class MockSession(Session):
         self.request = request
 
     def __setitem__(self, key, value):
-        session = self.ensure()
+        session = self.ensure(
+            sid = self.sid,
+            address = self.address
+        )
         return session.__setitem__(key, value)
 
     def ensure(self, *args, **kwargs):
@@ -242,6 +257,10 @@ class MemorySession(DataSession):
     def count(cls):
         return len(cls.SESSIONS)
 
+    @classmethod
+    def all(cls):
+        return cls.SESSIONS
+
 class FileSession(DataSession):
 
     SHELVE = None
@@ -278,10 +297,15 @@ class FileSession(DataSession):
     def count(cls):
         return len(cls.SHELVE)
 
+    @classmethod
+    def all(cls):
+        return cls.SHELVE
+
     @classmethod
     def open(cls, file_path = "session.shelve"):
         base_path = config.conf("APPIER_BASE_PATH", "")
         base_path = config.conf("SESSION_FILE_PATH", base_path)
+        if base_path and not os.path.exists(base_path): os.makedirs(base_path)
         file_path = os.path.join(base_path, file_path)
         cls.SHELVE = shelve.open(
             file_path,
