@@ -37,6 +37,7 @@ __copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
 __license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
+import os
 import re
 import sys
 import json
@@ -44,6 +45,7 @@ import copy
 import uuid
 import types
 import hashlib
+import threading
 import functools
 import subprocess
 
@@ -74,7 +76,13 @@ considered to be sequence based for python """
 
 defines = defines
 
+def to_limit(limit_s):
+    limit = int(limit_s)
+    if limit < 0: return 0
+    return limit
+
 def to_find(find_s):
+    if not find_s: return []
     find_t = type(find_s)
     if find_t == list: return find_s
     return [find_s]
@@ -102,7 +110,7 @@ between the normalized manned and the appier manner """
 
 FIND_TYPES = dict(
     skip = int,
-    limit = int,
+    limit = to_limit,
     find_s = legacy.UNICODE,
     find_d = to_find,
     find_i = bool,
@@ -1051,7 +1059,8 @@ def sanitize(function, kwargs):
         removal.append(name)
     for name in removal: del kwargs[name]
 
-def execute(args, command = None, path = None, shell = True, encoding = None):
+def execute(args, command = None, path = None, shell = None, encoding = None):
+    if shell == None: shell = os.name == "nt"
     if not encoding: encoding = sys.getfilesystemencoding()
     if command: args = command.split(" ")
     process = subprocess.Popen(
@@ -1091,3 +1100,23 @@ class FileTuple(tuple):
         file = open(path, "wb")
         try: file.write(contents)
         finally: file.close()
+
+class BaseThread(threading.Thread):
+    """
+    The top level thread class that is meant to encapsulate
+    a running base object and run it in a new context.
+
+    This base thread may be used to run a network loop allowing
+    a main thread to continue with execution logic.
+    """
+
+    def __init__(self, owner = None, daemon = False, *args, **kwargs):
+        threading.Thread.__init__(self, *args, **kwargs)
+        self.owner = owner
+        self.daemon = daemon
+
+    def run(self):
+        threading.Thread.run(self)
+        if not self.owner: return
+        self.owner.start()
+        self.owner = None
